@@ -306,7 +306,7 @@ calibrate.UncalGrid <- function(x, errors=0, calCurves='intcal20', timeRange=c(5
 #'
 #' @param x Either a vector of calibrated radiocarbon ages or an object of class CalGrid.
 #' @param CRAerrors A vector of standard deviations corresponding to each estimated radiocarbon age (ignored if x is a CalGrid object).
-#' @param roundyear An optional vector of IDs for each date (ignored if x is a CalGrid object).
+#' @param roundyear Whether the randomised estimate is rounded or not. Default is TRUE.
 #' @param  calCurves A string naming a calibration curve already provided with the rcarbon package (currently 'intcal20','intcal13','intcal13nhpine16','shcal20','shcal13','shcal13shkauri16',''marine13','marine20' and 'normal') or a custom curve provided as matrix/data.frame in three columns ("CALBP","C14BP","Error"). The default is the 'intcal20' curve and only one curve can currently be specified for all dates. 
 #' @param  eps Cut-off value for density calculation (for CalGrid objects only).
 #' @param  compact A logical variable indicating whether only uncalibrated ages with non-zero probabilities should be returned (for CalGrid objects only).
@@ -335,7 +335,7 @@ uncalibrate.default <- function(x, CRAerrors=0, roundyear=TRUE, calCurves='intca
     
     if (length(CRAerrors)==1){ CRAerrors <- rep(CRAerrors,length(x)) } 
     ## calCurve checks and set-up
-    if (class(calCurves) %in% c("matrix","data.frame")){
+    if (any(class(calCurves) %in% c("matrix","data.frame"))){
         calcurve <- as.matrix(calCurves)
         if (ncol(calcurve)!=3 | !all(sapply(calcurve,is.numeric))){
             stop("The custom calibration curve must have just three numeric columns.")
@@ -369,7 +369,7 @@ uncalibrate.CalGrid <- function(x, calCurves='intcal20', eps=1e-5, compact=TRUE,
     if (verbose){ print("Uncalibrating...") }
     names(x) <- c("calBP","PrDens")
     ## calCurve checks and set-up
-    if (class(calCurves) %in% c("matrix","data.frame")){
+    if (any(class(calCurves) %in% c("matrix","data.frame"))){
         calcurve <- as.matrix(calCurves)
         if (ncol(calcurve)!=3 | !all(sapply(calcurve,is.numeric))){
             stop("The custom calibration curve must have just three numeric columns.")
@@ -646,7 +646,7 @@ hpdi <- function(x, credMass=0.95){
 summary.CalDates<-function(object,prob=NA,calendar="BP",...) {
   
   foo = function(x,i){if(nrow(x)>=i){return(x[i,1:2])}else{return(c(NA,NA))}}
-  if (is.na(prob)) 
+  if (anyNA(prob)) 
   {
     prob = c(0.683,0.954)
     pnames = c("OneSigma","TwoSigma")
